==> eiffelstudio-18.11.10.2592.tar: F_code/C5/ew227.c <==
/*
 * Code for class EW_EXECUTE_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew227.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EXECUTE_INST}.inst_initialize */
void F746_4193 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc2);
	RTLR(5,tr2);
	RTLIU(6);
	
	RTEAA("inst_initialize", 745, Current, 2, 1, 8948);
	RTGC;
	RTHOOK(1);
	loc1 = F38_587(Current, arg1);
	RTHOOK(2);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2566[Dtype(loc1)-535])(RTCW(loc1));
	if ((EIF_BOOLEAN) (ti4_1 < ((EIF_INTEGER_32) 2L))) {
		RTHOOK(3);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_9_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		RTHOOK(4);
		tr1 = RTMS32_EX_H("m\000\000\000u\000\000\000s\000\000\000t\000\000\000 \000\000\000h\000\000\000a\000\000\000v\000\000\000e\000\000\000 \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000e\000\000\000a\000\000\000s\000\000\000t\000\000\000 \000\000\0002\000\000\000 \000\000\000a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000s\000\000\000",30,1115669107);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(5);
		{
			static EIF_TYPE_INDEX typarr0[] = {625,894,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
			tr1 = RTLNSMART(typres0.id);
		}
		F626_3479(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_8_) = (EIF_REFERENCE) tr1;
		RTHOOK(6);
		loc2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2441[Dtype(loc1)-538])(RTCW(loc1));
		RTHOOK(7);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2063[Dtype(loc2)-216])(loc2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
		RTHOOK(8);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tr2 = RTOUCR(253,F746_4197,(Current));
		tb1 = F895_5707(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(9);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) NULL;
		}
		RTHOOK(10);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R2065[Dtype(loc2)-216])(loc2);
		RTHOOK(11);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2063[Dtype(loc2)-216])(loc2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
		RTHOOK(12);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr2 = RTOUCR(253,F746_4197,(Current));
		tb1 = F895_5707(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(13);
			*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) NULL;
		}
		RTHOOK(14);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R2065[Dtype(loc2)-216])(loc2);
		for (;;) {
			tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R2064[Dtype(loc2)-216])(loc2);
			if (tb1) break;
			RTHOOK(15);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
			tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2063[Dtype(loc2)-216])(loc2);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(tr1)-509])(RTCW(tr1), tr2);
			RTHOOK(16);
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R2065[Dtype(loc2)-216])(loc2);
		}
		RTHOOK(17);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_9_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	}
	RTHOOK(18);
	RTLE;
	RTEE;
}

/* {EW_EXECUTE_INST}.execute */
void F746_4194 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(14);
	RTLR(0,loc5);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc7);
	RTLR(5,loc1);
	RTLR(6,loc6);
	RTLR(7,tr2);
	RTLR(8,loc2);
	RTLR(9,tr3);
	RTLR(10,loc3);
	RTLR(11,loc4);
	RTLR(12,loc8);
	RTLR(13,loc9);
	RTLIU(14);
	
	RTEAA("execute", 745, Current, 9, 1, 8949);
	RTGC;
	RTHOOK(1);
	loc5 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	tr1 = RTOUCR(53,F730_4124,(Current));
	loc5 = F643_3642(RTCW(loc5), tr1);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	loc5 = F643_3641(RTCW(tr1), loc5);
	RTHOOK(3);
	loc7 = F40_616(Current, loc5);
	RTHOOK(4);
	if ((EIF_BOOLEAN)(loc7 == NULL)) {
		RTHOOK(5);
		F908_6215(RTCW(arg1));
		RTHOOK(6);
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3360[Dtype(Current)-746])(Current);
		loc1 = F643_3642(RTCW(loc1), tr1);
		RTHOOK(7);
		tr1 = RTOUCR(17,F731_4126,(Current));
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		loc6 = F204_2294(RTCW(tr1), loc1, tr2);
		RTHOOK(8);
		if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_6_) != NULL)) {
			RTHOOK(9);
			tr1 = RTOUCR(17,F731_4126,(Current));
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tr3 = RTOUCR(13,F730_4116,(Current));
			tr2 = F643_3642(RTCW(tr2), tr3);
			tr3 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			loc2 = F203_2287(RTCW(tr1), tr2, tr3);
		} else {
			RTHOOK(10);
			loc2 = RTOUCR(246,F204_2293,(RTCV(RTOUCR(17,F731_4126,(Current)))));
		}
		RTHOOK(11);
		loc3 = (EIF_REFERENCE) NULL;
		RTHOOK(12);
		if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_7_) != NULL)) {
			RTHOOK(13);
			loc4 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		} else {
			RTHOOK(14);
			loc4 = F908_6194(RTCW(arg1));
		}
		RTHOOK(15);
		tr1 = RTOUCR(17,F731_4126,(Current));
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr3 = RTOUCR(21,F730_4119,(Current));
		tr2 = F643_3642(RTCW(tr2), tr3);
		loc4 = F203_2287(RTCW(tr1), tr2, loc4);
		RTHOOK(16);
		loc7 = F40_616(Current, loc6);
		RTHOOK(17);
		if ((EIF_BOOLEAN)(loc7 == NULL)) {
			RTHOOK(18);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(19);
			tb1 = '\0';
			if ((EIF_BOOLEAN)(loc2 != NULL)) {
				tr1 = RTOUCR(246,F204_2293,(RTCV(RTOUCR(17,F731_4126,(Current)))));
				tb2 = F895_5704(RTCW(loc2), tr1);
				tb1 = (EIF_BOOLEAN) !tb2;
			}
			if (tb1) {
				RTHOOK(20);
				tr1 = RTLNS(eif_new_type(536, 0x00).id, 536, _OBJSIZ_4_6_2_4_1_1_2_1_);
				F536_2989(RTCW(tr1), loc2);
				loc8 = (EIF_REFERENCE) tr1;
				RTHOOK(21);
				tb1 = F536_3020(RTCW(loc8));
				if ((EIF_BOOLEAN) !tb1) {
					RTHOOK(22);
					tr1 = RTMS32_EX_H("i\000\000\000n\000\000\000p\000\000\000u\000\000\000t\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000 \000\000\000n\000\000\000o\000\000\000t\000\000\000 \000\000\000f\000\000\000o\000\000\000u\000\000\000n\000\000\000d\000\000\000",20,82447716);
					RTAR(Current, tr1);
					*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
					RTHOOK(23);
					*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				} else {
					RTHOOK(24);
					tb1 = F536_3027(RTCW(loc8));
					if ((EIF_BOOLEAN) !tb1) {
						RTHOOK(25);
						tr1 = RTMS32_EX_H("i\000\000\000n\000\000\000p\000\000\000u\000\000\000t\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000 \000\000\000n\000\000\000o\000\000\000t\000\000\000 \000\000\000a\000\000\000 \000\000\000p\000\000\000l\000\000\000a\000\000\000i\000\000\000n\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000",27,1332975973);
						RTAR(Current, tr1);
						*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
						RTHOOK(26);
						*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
					}
				}
			}
			RTHOOK(27);
			if (*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_)) {
				RTHOOK(28);
				tr1 = RTLNS(eif_new_type(922, 0x00).id, 922, _OBJSIZ_6_3_0_0_0_0_0_0_);
				tr2 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
				tr3 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
				tr3 = *(EIF_REFERENCE *)(RTCW(tr3));
				F923_6485(RTCW(tr1), loc6, tr2, tr3, loc5, loc1, loc2, loc3, loc4);
				loc9 = (EIF_REFERENCE) tr1;
				RTHOOK(29);
				tr1 = F922_6471(RTCW(loc9));
				F908_6211(RTCW(arg1), tr1);
			}
		} else {
			RTHOOK(30);
			tr1 = F892_5610(RTCW(loc7));
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
			RTHOOK(31);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		}
	} else {
		RTHOOK(32);
		tr1 = F892_5610(RTCW(loc7));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		RTHOOK(33);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	}
	RTHOOK(34);
	RTLE;
	RTEE;
}

/* {EW_EXECUTE_INST}.init_ok */
EIF_BOOLEAN F746_4195 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_9_1_);
}


/* {EW_EXECUTE_INST}.execute_ok */
EIF_BOOLEAN F746_4196 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_);
}


/* {EW_EXECUTE_INST}.no_file_name */

EIF_REFERENCE F746_4197 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (253,RTMS32_EX_H("N\000\000\000O\000\000\000N\000\000\000E\000\000\000",4,1313820229));
}

/* {EW_EXECUTE_INST}.input_file_name */
EIF_REFERENCE F746_4198 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


/* {EW_EXECUTE_INST}.output_file_name */
EIF_REFERENCE F746_4199 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


/* {EW_EXECUTE_INST}.arguments */
EIF_REFERENCE F746_4200 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_8_);
}


void EIF_Minit227 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/ew227.c <==
/*
 * Code for class EW_EXECUTE_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew227.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EXECUTE_INST}.inst_initialize */
void F746_4200 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc2);
	RTLR(5,tr2);
	RTLIU(6);
	
	RTEAA("inst_initialize", 745, Current, 2, 1, 8955);
	RTGC;
	RTHOOK(1);
	loc1 = F38_587(Current, arg1);
	RTHOOK(2);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2568[Dtype(RTCW(loc1))-536])(loc1);
	if ((EIF_BOOLEAN) (ti4_1 < ((EIF_INTEGER_32) 2L))) {
		RTHOOK(3);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_9_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		RTHOOK(4);
		tr1 = RTMS32_EX_H("m\000\000\000u\000\000\000s\000\000\000t\000\000\000 \000\000\000h\000\000\000a\000\000\000v\000\000\000e\000\000\000 \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000e\000\000\000a\000\000\000s\000\000\000t\000\000\000 \000\000\0002\000\000\000 \000\000\000a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000s\000\000\000",30,1115669107);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(5);
		{
			static EIF_TYPE_INDEX typarr0[] = {625,894,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
			tr1 = RTLNSMART(typres0.id);
		}
		F626_3486(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_8_) = (EIF_REFERENCE) tr1;
		RTHOOK(6);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2443[Dtype(RTCW(loc1))-625])(loc1);
		loc2 = (EIF_REFERENCE) tr1;
		RTHOOK(7);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2065[Dtype(loc2)-287])(loc2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
		RTHOOK(8);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tr2 = RTOUCR(251,F746_4204, (Current));
		tb1 = F895_5728(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(9);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) NULL;
		}
		RTHOOK(10);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R2067[Dtype(loc2)-287])(loc2);
		RTHOOK(11);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2065[Dtype(loc2)-287])(loc2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
		RTHOOK(12);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		tr2 = RTOUCR(251,F746_4204, (Current));
		tb1 = F895_5728(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(13);
			*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) NULL;
		}
		RTHOOK(14);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R2067[Dtype(loc2)-287])(loc2);
		for (;;) {
			tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R2066[Dtype(loc2)-287])(loc2);
			if (tb1) break;
			RTHOOK(15);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
			tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2065[Dtype(loc2)-287])(loc2);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(tr1))-625])(tr1, tr2);
			RTHOOK(16);
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R2067[Dtype(loc2)-287])(loc2);
		}
		RTHOOK(17);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_9_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	}
	RTHOOK(18);
	RTLE;
	RTEE;
}

/* {EW_EXECUTE_INST}.execute */
void F746_4201 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(14);
	RTLR(0,loc5);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc7);
	RTLR(5,loc1);
	RTLR(6,loc6);
	RTLR(7,tr2);
	RTLR(8,loc2);
	RTLR(9,tr3);
	RTLR(10,loc3);
	RTLR(11,loc4);
	RTLR(12,loc8);
	RTLR(13,loc9);
	RTLIU(14);
	
	RTEAA("execute", 745, Current, 9, 1, 8956);
	RTGC;
	RTHOOK(1);
	loc5 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	tr1 = RTOUCR(53,F730_4131, (Current));
	loc5 = F643_3649(RTCW(loc5), tr1);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	tr1 = F643_3648(RTCW(tr1), loc5);
	loc5 = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	loc7 = F40_616(Current, loc5);
	RTHOOK(4);
	if ((EIF_BOOLEAN)(loc7 == NULL)) {
		RTHOOK(5);
		F908_6236(RTCW(arg1));
		RTHOOK(6);
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3367[Dtype(Current)-746])(Current);
		loc1 = F643_3649(RTCW(loc1), tr1);
		RTHOOK(7);
		tr1 = RTOUCR(17,F731_4133, (Current));
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		loc6 = F204_2296(RTCW(tr1), loc1, tr2);
		RTHOOK(8);
		if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_6_) != NULL)) {
			RTHOOK(9);
			tr1 = RTOUCR(17,F731_4133, (Current));
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tr3 = RTOUCR(13,F730_4123, (Current));
			tr2 = F643_3649(RTCW(tr2), tr3);
			tr3 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			loc2 = F203_2289(RTCW(tr1), tr2, tr3);
		} else {
			RTHOOK(10);
			loc2 = RTOUCR(246,F204_2295, (RTCV(RTOUCR(17,F731_4133, (Current)))));
		}
		RTHOOK(11);
		loc3 = (EIF_REFERENCE) NULL;
		RTHOOK(12);
		if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_7_) != NULL)) {
			RTHOOK(13);
			loc4 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
		} else {
			RTHOOK(14);
			loc4 = F908_6215(RTCW(arg1));
		}
		RTHOOK(15);
		tr1 = RTOUCR(17,F731_4133, (Current));
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr3 = RTOUCR(21,F730_4126, (Current));
		tr2 = F643_3649(RTCW(tr2), tr3);
		tr1 = F203_2289(RTCW(tr1), tr2, loc4);
		loc4 = (EIF_REFERENCE) tr1;
		RTHOOK(16);
		loc7 = F40_616(Current, loc6);
		RTHOOK(17);
		if ((EIF_BOOLEAN)(loc7 == NULL)) {
			RTHOOK(18);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(19);
			tb1 = '\0';
			if ((EIF_BOOLEAN)(loc2 != NULL)) {
				tr1 = RTOUCR(246,F204_2295, (RTCV(RTOUCR(17,F731_4133, (Current)))));
				tb2 = F895_5725(RTCW(loc2), tr1);
				tb1 = (EIF_BOOLEAN) !tb2;
			}
			if (tb1) {
				RTHOOK(20);
				loc8 = RTLNS(eif_new_type(536, 0x00).id, 536, _OBJSIZ_4_6_2_4_1_1_2_1_);
				F536_2991(RTCW(loc8), loc2);
				RTHOOK(21);
				tb1 = F536_3026(RTCW(loc8));
				if ((EIF_BOOLEAN) !tb1) {
					RTHOOK(22);
					tr1 = RTMS32_EX_H("i\000\000\000n\000\000\000p\000\000\000u\000\000\000t\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000 \000\000\000n\000\000\000o\000\000\000t\000\000\000 \000\000\000f\000\000\000o\000\000\000u\000\000\000n\000\000\000d\000\000\000",20,82447716);
					RTAR(Current, tr1);
					*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
					RTHOOK(23);
					*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				} else {
					RTHOOK(24);
					tb1 = F536_3033(RTCW(loc8));
					if ((EIF_BOOLEAN) !tb1) {
						RTHOOK(25);
						tr1 = RTMS32_EX_H("i\000\000\000n\000\000\000p\000\000\000u\000\000\000t\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000 \000\000\000n\000\000\000o\000\000\000t\000\000\000 \000\000\000a\000\000\000 \000\000\000p\000\000\000l\000\000\000a\000\000\000i\000\000\000n\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000",27,1332975973);
						RTAR(Current, tr1);
						*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
						RTHOOK(26);
						*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
					}
				}
			}
			RTHOOK(27);
			if (*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_)) {
				RTHOOK(28);
				loc9 = RTLNS(eif_new_type(922, 0x00).id, 922, _OBJSIZ_6_3_0_0_0_0_0_0_);
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
				tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
				F923_6506(RTCW(loc9), loc6, *(EIF_REFERENCE *)(Current + _REFACS_8_), tr1, loc5, loc1, loc2, loc3, loc4);
				RTHOOK(29);
				tr1 = F922_6492(RTCW(loc9));
				F908_6232(RTCW(arg1), tr1);
			}
		} else {
			RTHOOK(30);
			tr1 = F892_5631(RTCW(loc7));
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
			RTHOOK(31);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		}
	} else {
		RTHOOK(32);
		tr1 = F892_5631(RTCW(loc7));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		RTHOOK(33);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	}
	RTHOOK(34);
	RTLE;
	RTEE;
}

/* {EW_EXECUTE_INST}.init_ok */
EIF_BOOLEAN F746_4202 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_9_1_);
}


/* {EW_EXECUTE_INST}.execute_ok */
EIF_BOOLEAN F746_4203 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_9_0_);
}


/* {EW_EXECUTE_INST}.no_file_name */

EIF_REFERENCE F746_4204 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (251,RTMS32_EX_H("N\000\000\000O\000\000\000N\000\000\000E\000\000\000",4,1313820229));
}

void EIF_Minit227 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
